==> checker-framework-3.52.0.zip: annotated-jdk/src/jdk.jlink/share/classes/jdk/tools/jmod/JmodOutputStream.java <==
/*
 * Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package jdk.tools.jmod;

import org.checkerframework.dataflow.qual.Pure;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.UncheckedIOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;
import jdk.internal.jmod.JmodFile;
import static jdk.internal.jmod.JmodFile.*;

class JmodOutputStream extends OutputStream implements AutoCloseable {

    static JmodOutputStream newOutputStream(Path file) throws IOException;

    public void writeEntry(InputStream in, Section section, String name) throws IOException;

    public void writeEntry(byte[] bytes, Section section, String path) throws IOException;

    public void writeEntry(InputStream in, Entry e) throws IOException;

    @Pure
    public boolean contains(Section section, String path);

    @Override
    public void write(int b) throws IOException;

    @Override
    public void close() throws IOException;
}

==> checker-framework-3.53.1.zip: annotated-jdk/src/jdk.jlink/share/classes/jdk/tools/jmod/JmodOutputStream.java <==
/*
 * Copyright (c) 2016, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package jdk.tools.jmod;

import org.checkerframework.dataflow.qual.Pure;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.UncheckedIOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;
import jdk.internal.jmod.JmodFile;
import java.time.LocalDateTime;
import static jdk.internal.jmod.JmodFile.*;

class JmodOutputStream extends OutputStream implements AutoCloseable {

    static JmodOutputStream newOutputStream(Path file, LocalDateTime date, int compressLevel) throws IOException;

    public void writeEntry(InputStream in, Section section, String name) throws IOException;

    public void writeEntry(byte[] bytes, Section section, String path) throws IOException;

    public void writeEntry(InputStream in, Entry e) throws IOException;

    @Pure
    public boolean contains(Section section, String path);

    @Override
    public void write(int b) throws IOException;

    @Override
    public void close() throws IOException;
}
